pub struct QueuedMessage {
pub context: Py<PyContext>,
pub method: MethodSpecifier,
pub bytes: FrozenBuffer,
pub local_state: Py<PyAny>,
pub response_port: Py<PyAny>,
}Expand description
Message sent through the queue in queue-dispatch mode. Contains pre-resolved components ready for Python consumption.
Fields
context: Py<PyContext>method: MethodSpecifierbytes: FrozenBufferlocal_state: Py<PyAny>response_port: Py<PyAny>Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for QueuedMessage
impl<'py> IntoPyObject<'py> for QueuedMessage
Sourcetype Target = QueuedMessage
type Target = QueuedMessage
The Python output type
Sourcetype Output = Bound<'py, <QueuedMessage as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <QueuedMessage as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for QueuedMessage
impl PyClass for QueuedMessage
Sourceimpl PyClassImpl for QueuedMessage
impl PyClassImpl for QueuedMessage
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Message sent through the queue in queue-dispatch mode.
/// Contains pre-resolved components ready for Python consumption.
const RAW_DOC: &'static CStr = /// Message sent through the queue in queue-dispatch mode. /// Contains pre-resolved components ready for Python consumption.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<QueuedMessage>
type ThreadChecker = SendablePyClass<QueuedMessage>
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForQueuedMessage
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder QueuedMessage
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder QueuedMessage
Sourceimpl PyTypeInfo for QueuedMessage
impl PyTypeInfo for QueuedMessage
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for QueuedMessage